@@ -62,7 +62,7 @@
 #define HAVE_TZSET 1
 
 /* Define to use the MaxMind DB library */
-#define HAVE_MAXMINDDB 1
+/* #undef HAVE_MAXMINDDB */
 /* MaxmindDB version */
 #define MAXMINDDB_VERSION ""
 
@@ -80,7 +80,7 @@
 #define HAVE_GETIFADDRS 1
 
 /* Define if LIBSSH support is enabled */
-#define HAVE_LIBSSH 1
+/* #undef HAVE_LIBSSH */
 
 /* Define if you have the 'dlget' function. */
 /* #undef HAVE_DLGET */
@@ -92,16 +92,16 @@
 /* #undef HAVE_HEIMDAL_KERBEROS */
 
 /* Define to 1 if you have the `krb5_pac_verify' function. */
-#define HAVE_KRB5_PAC_VERIFY 1
+/* #undef HAVE_KRB5_PAC_VERIFY */
 
 /* Define to 1 if you have the `krb5_c_fx_cf2_simple' function. */
-#define HAVE_KRB5_C_FX_CF2_SIMPLE 1
+/* #undef HAVE_KRB5_C_FX_CF2_SIMPLE */
 
 /* Define to 1 if you have the `decode_krb5_enc_tkt_part' function. */
-#define HAVE_DECODE_KRB5_ENC_TKT_PART 1
+/* #undef HAVE_DECODE_KRB5_ENC_TKT_PART */
 
 /* Define to 1 if you have the `encode_krb5_enc_tkt_part' function. */
-#define HAVE_ENCODE_KRB5_ENC_TKT_PART 1
+/* #undef HAVE_ENCODE_KRB5_ENC_TKT_PART */
 
 /* Define to 1 if you have the `inflatePrime' function. */
 #define HAVE_INFLATEPRIME 1
@@ -113,13 +113,13 @@
 /* #undef HAVE_ISSETUGID */
 
 /* Define to use kerberos */
-#define HAVE_KERBEROS 1
+/* #undef HAVE_KERBEROS */
 
 /* Define to use nghttp2 */
-#define HAVE_NGHTTP2 1
+/* #undef HAVE_NGHTTP2 */
 
 /* Define to use nghttp3 */
-#define HAVE_NGHTTP3 1
+/* #undef HAVE_NGHTTP3 */
 
 /* Define to use the libcap library */
 #define HAVE_LIBCAP 1
@@ -128,7 +128,7 @@
 #define HAVE_LIBGNUTLS 1
 
 /* Define to 1 if GnuTLS was built with pkcs11 support. */
-#define HAVE_GNUTLS_PKCS11 1
+/* #undef HAVE_GNUTLS_PKCS11 */
 
 /* Enable libnl support */
 #define HAVE_LIBNL 1
@@ -140,14 +140,14 @@
 #define HAVE_LIBPCAP 1
 
 /* Define to 1 if you have the `smi' library (-lsmi). */
-#define HAVE_LIBSMI 1
+/* #undef HAVE_LIBSMI */
 
 /* Define to 1 if libsmi exports a version string (and that symbol is visible). */
-#define HAVE_SMI_VERSION_STRING 1
+/* #undef HAVE_SMI_VERSION_STRING */
 
 /* Define to use xxhash library */
-#define HAVE_XXHASH 1
-#define XXHASH_VERSION_STRING "0.8.3"
+/* #undef HAVE_XXHASH */
+#define XXHASH_VERSION_STRING ""
 
 /* Define to use zlib library */
 #define HAVE_ZLIB 1
@@ -158,7 +158,7 @@
 
 /* Define to use the minizip library */
 #define HAVE_MINIZIP 1
-#define MINIZIP_VERSION "1.3.1"
+#define MINIZIP_VERSION "1.3.2"
 
 /* Define to use the minizip-ng library */
 /* #undef HAVE_MINIZIPNG */
@@ -168,17 +168,17 @@
 /* #undef HAVE_MZCOMPAT_DOS_DATE */
 
 /* Define to use brotli library */
-#define HAVE_BROTLI 1
+/* #undef HAVE_BROTLI */
 
 /* Define to use lz4 library */
-#define HAVE_LZ4 1
+/* #undef HAVE_LZ4 */
 
 /* Check for lz4frame */
-#define HAVE_LZ4FRAME_H 1
+/* #undef HAVE_LZ4FRAME_H */
 
 /* Define to use snappy library */
-#define HAVE_SNAPPY 1
-#define SNAPPY_VERSION "1.2.2"
+/* #undef HAVE_SNAPPY */
+#define SNAPPY_VERSION ""
 
 /* Define to use zstd library */
 #define HAVE_ZSTD 1
@@ -199,7 +199,7 @@
 /* #undef LUA_INTEGER_SIZE */
 
 /* Define to use MIT kerberos */
-#define HAVE_MIT_KERBEROS 1
+/* #undef HAVE_MIT_KERBEROS */
 
 /* Define to 1 if you have the <netdb.h> header file. */
 #define HAVE_NETDB_H 1
@@ -244,22 +244,22 @@
 #define HAVE_PWD_H 1
 
 /* Define to 1 if you want to playing SBC by standalone BlueZ SBC library */
-#define HAVE_SBC 1
+/* #undef HAVE_SBC */
 
 /* Define to 1 if you have the SpanDSP library. */
-#define HAVE_SPANDSP 1
+/* #undef HAVE_SPANDSP */
 
 /* Define to 1 if you have the bcg729 library. */
-#define HAVE_BCG729 1
+/* #undef HAVE_BCG729 */
 
 /* Define to 1 if you have the opencore-amrnb library. */
-#define HAVE_AMRNB 1
+/* #undef HAVE_AMRNB */
 
 /* Define to 1 if you have the ilbc library. */
-#define HAVE_ILBC 1
+/* #undef HAVE_ILBC */
 
 /* Define to 1 if you have the opus library. */
-#define HAVE_OPUS 1
+/* #undef HAVE_OPUS */
 
 /* Define to 1 if you have the `setresgid' function. */
 #define HAVE_SETRESGID 1
